@@ -385,12 +385,13 @@ class Transcoder:
         sample_rate: Optional[int] = None,
         audio_index: int = None,
         video_index: int = None,
+        audio_codec: str = None,
         mix_down=True,
         extra_args: list = None,
         on_progress: ProgressHandler = None,
         audiogram_op: Union[AudiogramOp, dict] = None,
         op: FfmpegOperation = None,
-    ):
+    ) -> str:
         op = op or self.op()
         op.input_files = [input] if isinstance(input, str) else list(input)
         infos = op.input_files_info
@@ -486,16 +487,23 @@ class Transcoder:
                 ]
             )
 
-        if not did_mix:
-            audio_infos = [
-                infos[i].audio_stream
-                for i in audio_indices
-                if infos[i].audio_stream_maybe
-            ]
-            if not audio_infos:
-                raise UnitranscodeFormatError(
-                    'Input does not have any audio channels!'
-                )
+        audio_infos = [
+            infos[i].audio_stream
+            for i in audio_indices
+            if infos[i].audio_stream_maybe
+        ]
+        if not audio_infos:
+            raise UnitranscodeFormatError(
+                'Input does not have any audio channels!'
+            )
+
+        if audio_codec:
+            if not did_mix and audio_infos[0]['codec_name'] == audio_codec:
+                args.extend(['-c:a', 'copy'])
+            else:
+                args.extend(['-c:a', audio_codec])
+
+        if not did_mix and not audio_codec:
             audio_info = audio_infos[0]
             incompatible = False
             if (
@@ -584,16 +592,41 @@ class Transcoder:
         op: FfmpegOperation = None,
     ) -> str:
         op = op or self.op()
-        filter_str = '+'.join(
-            f'between(t,{start},{end})' for start, end in cuts
+        info = self.info(in_file)
+        has_video = bool(info.video_stream_maybe)
+        has_audio = bool(info.audio_stream_maybe)
+        filter_cmds = []
+        stream_names = []
+        for i, (lt, rt) in enumerate(cuts):
+            cmd = ''
+            name = ''
+            if has_video:
+                cmd += f'[0:v]trim={lt}:{rt},setpts=PTS-STARTPTS[v{i}];'
+                name += f'[v{i}]'
+            if has_audio:
+                cmd += f'[0:a]atrim={lt}:{rt},asetpts=PTS-STARTPTS[a{i}];'
+                name += f'[a{i}]'
+            filter_cmds.append(cmd)
+            stream_names.append(name)
+        video_output = '[v]' * has_video
+        audio_output = '[a]' * has_audio
+        complex_filter = (
+            ''.join(filter_cmds)
+            + ''.join(stream_names)
+            + f'concat=n={str(len(stream_names))}'
+            + f':v={[0, 1][has_video]}:a={[0, 1][has_audio]}'
+            + video_output
+            + audio_output
         )
 
         self.ffmpeg(
             *('-i', in_file),
-            *('-vf', f"select='{filter_str}',setpts=N/FRAME_RATE/TB"),
-            *('-af', f"aselect='{filter_str}',asetpts=N/SR/TB"),
+            *('-filter_complex', complex_filter),
+            *('-map', video_output) * has_video,
+            *('-map', audio_output) * has_audio,
+            '-shortest',
             output_file,
-            duration_s=self.info(in_file).duration_s if on_progress else None,
+            duration_s=sum(b - a for a, b in cuts),
             on_progress=on_progress,
             op=op,
         )
